"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const ast_spec_1 = require("@typescript-eslint/types/dist/generated/ast-spec");
const DCIRuleHelpers_1 = require("../DCIRuleHelpers");
exports.default = (0, DCIRuleHelpers_1.createRule)({
    name: "atomic-role-binding",
    create(context) {
        return (0, DCIRuleHelpers_1.contextRules)(context, {
            BlockStatement(node) {
                const dciContext = (0, DCIRuleHelpers_1.isInContext)();
                if (!dciContext)
                    return;
                //console.log(dciContext.roles.keys());
                // Filter all assignments
                const assignments = node.body
                    .map((s) => {
                    return s.type == ast_spec_1.AST_NODE_TYPES.ExpressionStatement &&
                        s.expression.type == ast_spec_1.AST_NODE_TYPES.AssignmentExpression &&
                        s.expression.left.type == ast_spec_1.AST_NODE_TYPES.Identifier &&
                        dciContext.roles.has(s.expression.left.name)
                        ? s.expression.left
                        : null;
                })
                    .filter((s) => !!s);
                // Filter out duplicates
                const assignmentMap = new Map(assignments.map((a) => [a.name, a]));
                // Check if all assignments are made in the same block.
                const allRoles = new Set(dciContext.roles.keys());
                if (assignmentMap.size > 0) {
                    if (assignmentMap.size < allRoles.size) {
                        context.report({
                            loc: node.loc,
                            messageId: "tooFew",
                            data: {
                                missing: Array.from(allRoles.values())
                                    .filter((r) => !assignments.find((a) => a.name == r))
                                    .join(","),
                            },
                        });
                    }
                    else {
                        // Binding ok!
                    }
                }
            },
        });
    },
    meta: {
        docs: {
            description: "All Roles must be bound (reassigned) in the same function.",
            recommended: "error",
        },
        messages: {
            tooFew: `All Roles must be bound (reassigned) in the same function. Missing: {{missing}}`,
            alreadyDeclared: `Roles are already bound elsewhere in the Context`,
        },
        type: "problem",
        schema: [],
    },
    defaultOptions: [],
});
//# sourceMappingURL=atomic-role-binding.js.map