"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const utils_1 = require("@typescript-eslint/utils");
const DCIRuleHelpers_1 = require("../DCIRuleHelpers");
exports.default = (0, DCIRuleHelpers_1.createRule)({
    name: "immutable-roles",
    create(context) {
        return (0, DCIRuleHelpers_1.contextRules)(context, {
            FunctionDeclaration(node) {
                const dciContext = (0, DCIRuleHelpers_1.isContext)(node);
                if (!dciContext)
                    return;
                for (const role of dciContext.roles.values()) {
                    if (role.kind == "let" || role.kind == "var") {
                        context.report({
                            loc: role.id.loc,
                            messageId: "notImmutableVar",
                        });
                    }
                }
            },
            AssignmentExpression(node) {
                const dciContext = (0, DCIRuleHelpers_1.isInContext)();
                if (!dciContext)
                    return;
                if (node.left.type != utils_1.AST_NODE_TYPES.Identifier)
                    return;
                if (dciContext.roles.has(node.left.name)) {
                    context.report({
                        loc: node.loc,
                        messageId: "immutableAssignment",
                    });
                }
            },
        });
    },
    meta: {
        docs: {
            description: "A Role should be immutable, to prevent reassignment when the Context is executing.",
            recommended: "warn",
        },
        messages: {
            notImmutableVar: `A Role should be immutable, to prevent reassignment when the Context is executing. Use "const" instead.`,
            immutableAssignment: `A Role should be immutable, to prevent reassignment when the Context is executing.`,
        },
        type: "suggestion",
        schema: [],
    },
    defaultOptions: [],
});
//# sourceMappingURL=immutable-roles.js.map